package footfall.displays;

import java.awt.*;
import java.awt.event.*;
import javax.swing.*;

/**
  Display the footfall pressure by color depth: Bright red is highest pressure and white is no pressure.
  @author Chirag Mehta (chirag@chir.ag)
*/

public class DisplayFootFall extends Display
{
  /**
    Display the footfall pressure by color depth: Bright red is highest pressure and white is no pressure. Turned on by default.
  */
  public DisplayFootFall()
  {
    super();
    setBackground(new Color(0.6f, 0.6f, 0.6f));
  }

  /**
    If enabled, draw the footfall pressure grid.
    @param prd Pressure Data for each cell in the frame
    @param m Maximum pressure limit for the frame
    @param fw Frame width
    @param fh Frame Height
    @param fname Frame Name/Caption
  */
  public void updateDisplay(float[][] prd, float m, int fw, int fh, String fname)
  {
    if(!this.enabled) return;

    Graphics g = this.getGraphics();

    if(g != null)
    {
      Dimension d = getSize();
      int w = d.width, h = d.height;
      float clr = 0;

      g.clearRect(0,0,w,27);
      g.drawString(fname, 10, 20);

      for(int i = 0; i < fh; i++)
      {
        for(int j = 0; j < fw * 2; j++)
        {
          if(j < fw)
            clr = 1-prd[fh-1-i][j]/m;
          else
            clr = 1-prd[i][j]/m;
          if(clr < 0) clr = 0;
          g.setColor(new Color(1, clr, clr));
          g.fillRect(1+j*w/fw/2, 28+i*(h-28)/fh, (1+(j+1)*w/fw/2)-(1+j*w/fw/2)-1, (28+(i+1)*(h-28)/fh)-(28+i*(h-28)/fh)-1);
        }
      }
    }
  }
}